#
# desktop_choice_gui.py: choose desktop
#
# Copyright 2002 Red Hat, Inc.
#
# This software may be freely redistributed under the terms of the GNU
# library public license.
#
# You should have received a copy of the GNU Library Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

import gtk
import gobject
import string
import gui
from iw_gui import *
from rhpl.translate import _, N_
from constants import productName
from flags import flags

NOT_ENOUGH_CAPACITY = N_("/usr or / partition doesn't have enough space for the packages you selected. Please enlarge the disk partition (to total size of packages + 500MB or more), or reduce packages to be installed.")

class DesktopChoiceWindow (InstallWindow):		

    windowTitle = N_("Package Defaults")
    htmlTag = "pkg-default"

    def __init__ (self, ics):
	InstallWindow.__init__ (self, ics)
        ics.setGrabNext (1)
	self.ics = ics

    def getNext(self):
	if self.customizeRadio.get_active():
	    self.dispatch.skipStep("package-selection", skip = 0)
	    self.grpset.unselectAll()
	    self.grpset.selectGroup("base")
	    self.grpset.selectGroup("core")
	elif self.minimalRadio.get_active():
	    if self.size_of_min + 500 > self.capacity:
		rc = self.intf.messageWindow(_("Warning"), _(NOT_ENOUGH_CAPACITY),
			 type="warning", default="ok", custom_icon ="warning")
		raise gui.StayOnScreen
	    self.dispatch.skipStep("package-selection", skip = 1)
	    self.grpset.unselectAll()
	    self.grpset.selectGroup("base")
	    self.grpset.selectGroup("core")
	else:
	    if self.size_of_all + 500 > self.capacity:
		rc = self.intf.messageWindow(_("Warning"), _(NOT_ENOUGH_CAPACITY),
			 type="warning", default="ok", custom_icon ="warning")
		raise gui.StayOnScreen
	    self.dispatch.skipStep("package-selection", skip = 1)
	    self.grpset.unselectAll()
	    self.grpset.selectGroup("everything")

	return None
    
    # WelcomeWindow tag="wel"
    def getScreen (self, intf, instclass, dispatch, grpset, partitions, diskset):

	self.intf = intf
	self.dispatch = dispatch
	self.grpset = grpset
	self.partitions = partitions
	self.diskset = diskset

	# Get the capacity of the disk partition.
	if self.partitions.getRequestByMountPoint('/usr') is None:
	    self.capacity = self.partitions.getRequestByMountPoint('/').getActualSize(self.partitions, self.diskset)
	else:
	    self.capacity = self.partitions.getRequestByMountPoint('/usr').getActualSize(self.partitions, self.diskset)

	# Calculate the number of packages and its total size.
	self.grpset.unselectAll()
	self.grpset.selectGroup("base")
	self.grpset.selectGroup("core")
	self.size_of_min = self.grpset.size()
	(gset, pset) = self.grpset.getSelectionState()
	pn_of_min = 0
	for (pkg, (usecount, manual_state)) in pset:
	    if usecount > 0:
		pn_of_min = pn_of_min + 1
	self.grpset.unselectAll()
	self.grpset.selectGroup("everything")
	self.size_of_all = self.grpset.size()
	(gset, pset) = self.grpset.getSelectionState()
	pn_of_all = 0
	for (pkg, (usecount, manual_state)) in pset:
	    if usecount > 0:
		pn_of_all = pn_of_all + 1

	vbox = gtk.VBox (gtk.FALSE, 0)
	vbox.set_border_width (5)
	hbox = gtk.HBox (gtk.FALSE, 0)

	labeltxt = _("Selection of packages to be installed.")
	label = gui.WrappingLabel(labeltxt)

	hbox.pack_start (label, gtk.FALSE, gtk.FALSE, 0)
	vbox.pack_start (hbox, gtk.FALSE, gtk.FALSE, 0)
	
	self.minimalRadio = gtk.RadioButton (None, _("Minimal (%s packages, total size: %sM)") % (pn_of_min, self.size_of_min))
	self.everythingRadio = gtk.RadioButton (self.minimalRadio, _("All     (%s packages, total size: %sM)") % (pn_of_all, self.size_of_all))
	self.customizeRadio = gtk.RadioButton (self.minimalRadio, _("Customize the set of packages in the next step"))
	vbox2 = gtk.VBox (gtk.FALSE)
	vbox2.pack_start (self.minimalRadio, gtk.FALSE, gtk.FALSE, 0)
	vbox2.pack_start (self.everythingRadio, gtk.FALSE, gtk.FALSE, 0)
	vbox2.pack_start (self.customizeRadio, gtk.FALSE, gtk.FALSE, 0)
	al = gtk.Alignment(0.5, 0)
	al.add (vbox2)
	
	vbox.pack_start (al, gtk.FALSE, gtk.FALSE, 25)
	self.everythingRadio.set_active(1)
	    
	big_al = gtk.Alignment (0.5, 0.2)
	big_al.add (vbox)
	return big_al
